@@ -9,19 +9,19 @@ mod event;
 mod fun;
 mod instantiate;
 mod restore;
-mod ri;
+// mod ri;
 mod storage;
 mod transfer;
 
-pub use self::{
-    derive::Host,
-    ri::{NoRuntimeInterfaces, RuntimeInterfaces},
-};
+pub use self::derive::Host;
+use ceres_sandbox::RuntimeInterfaces;
+
+/// Seal calls
+pub type SealCall =
+    ceres_executor::derive::HostCall<&'static str, &'static str, ceres_sandbox::Sandbox>;
 
 /// Pallet contract host functions
-pub fn pallet_contracts(
-    interfaces: impl ri::RuntimeInterfaces,
-) -> Vec<ceres_executor::derive::HostParcel<&'static str, &'static str, ceres_sandbox::Sandbox>> {
+pub fn pallet_contracts(ri: Option<impl RuntimeInterfaces>) -> Vec<SealCall> {
     let mut wasm = vec![
         chain::Gas::pack(),
         chain::BlockNumber::pack(),
@@ -45,8 +45,8 @@ pub fn pallet_contracts(
         instantiate::SealInstantiate::pack(),
     ];
 
-    if ri::RuntimeInterfaces::enabled(&interfaces) {
-        wasm.append(&mut ri::RuntimeInterfaces::pack(&interfaces))
+    if let Some(interfaces) = ri {
+        wasm.append(&mut RuntimeInterfaces::pack(&interfaces))
     }
 
     wasm
